# ABOUT ------------------------------------------------------------------
# 
# TIgGER: Tool for Immunoglobulin Genotype Elucidation via Rep-Seq
#
# Requires a tab-delimited data file (required columns listed in config file).
# Finds undocumented V alleles, infers an individual's repertoire,
# and uses this data to correct allele calls.
# Corrected allele calls are added as a new column "V_CALL_GENOTYPED".
#
# Instructions: Modify the directories and file inputs below, then source this.
# Be sure to have echo = T, if you want the parameters below saved.
# 
# Created: 2013-05
# Coded by Daniel Gadala-Maria
# Copyright Kleinstein Lab (http://medicine.yale.edu/lab/kleinstein)

# FILE LOCATIONS ----------------------------------------------------------
setwd("C:/Users/Daniel Gadala-Maria/Documents/Kleinstein/Genotyping/") # Set working directory
funcs_loc = "C:/Users/Daniel Gadala-Maria/repos/tigger/TIgGER_functions.R"
tigger_loc = "C:/Users/Daniel Gadala-Maria/repos/tigger/TIgGER.R"

range = list(119:120,147:148,157:158,169:170,171:172)
for (rang in 1:length(range)){

twins = paste("Twin_", range[[rang]], sep="")

# SUBFOLDER NAME ----------------------------------------------------------
# Be sure to modify these for your specific run. "run" will be a subfolder for resuls
run = paste(twins,collapse="+")
if (!file.exists(run)){ dir.create(file.path(getwd(), run)) }
sink(paste(run, "/config.txt", sep=""),) # Parameters for the run will be saved in this file.

# KEY PARAMETERS ----------------------------------------------------------
#clip_tab_file = "C:/Users/Daniel Gadala-Maria/Documents/Kleinstein/Datasets/Bolen Twins/twinStudy_ClipTab_withFRdata_goodSeqs_deident_igonly.tab" # Tab file with data. Req'd columns listed under "Tab-delimited file reading"
clip_tab_file = "C:/Users/Daniel Gadala-Maria/Documents/Kleinstein/Datasets/Bolen Twins/twinStudy_runs5to17_allSeqs_withFRdata.Rd"
#clip_tab_file = "GMC2_CLIP_genotyped_meta.tab" 
additional = "*" # Additional columns for when we read the above with SQL
#add_cond = "where FUNCTIONAL='T' AND (TIME='-8d' OR TIME='-2d' OR TIME='-1h')" # Additional conditions for when we read the above with SQL
rep_file = "C:/Users/Daniel Gadala-Maria/Documents/Kleinstein/Datasets/IMGT/IMGT Ig Sequences nameEdit 2014-09-29.fasta" # Fasta file. Database V germline sequences

# STEPS TO PERFORM --------------------------------------------------------
find_new_alleles = T
find_genotype = T
correct_v_assignments = T
quiet = F # Minimize mid-run output?
clean = F # Output nothing except personal repertoire and updated tab-delim file

# OTHER PARAMETERS --------------------------------------------------------
# You shouldn't need to mess with these, usually

# Polymorphism detection parameters
y_i = 1/8 # y intercept for finding polymorphisms
i_a = 0.05 # Alpha for y-intercept calcualtion (t-test-based)
allele_min = 10^-3 # What frequency makes an allele too rare to be included, for polymorpishm detection?
bcp = T # Apply above cutoff in a binomial manner for polymorphism detection?
bcpa = 0.05 # Alpha cutoff for above?
mmin = 1 # What is the min mutation count allowable for seqs used in line fitting?
mmax = 10 # What is the max mutation count allowable for seqs used in line fitting?
jpct = .1 # Largest frac. of perfect matches belonging to a single j-junction combo

#Genotyping parameters
acg =  1/8 # fraction of a gene's calls that an allele must constitute for genotype inclusion
bcg = F # Binomial cutoff for Genotyping?
acga = 0.05 # alpha cutoff for above
gene_min= 1e-3 # Minimum for a gene to be incl. in genotype. Can be a frac. or no. of seqs.
which_to_realign = c("underscore", "uncalled", "all", "none")[1] # Which repseqs to realign prior to genotyping? Just change the index.
resolve_imgt_ambigs = T # If you don't trust IMGT calls, we'll do an alignment to resolve ambiguous but unmutated sequences.

# Tab-delimited file reading
gap_seq_col = "SEQUENCE_GAP" # Required column. Contains the IMGT-gapped nt sequence
v_call_col  = "V_CALL"       # Required column. Contains the V allele name
j_call_col  = "J_CALL"       # Required column. Contains the J allele name
#v_len_col   = "V_GAP_LENGTH" # Required column. Contains the nt legnth of the IMGT-gapped V
v_len_col   = "V_GERM_LENGTH" # Required column. Contains the nt legnth of the IMGT-gapped V
junc_col    = "JUNCTION"     # Required column. Contains the nt sequence of the junction
# "V_CALL_GENOTYPED" is the column for corrected V calls in the output file

# Start things off!
sink()
logfile = paste(run,"/log.txt", sep="")
source(funcs_loc, echo=F)
source(tigger_loc, echo=F)

}
