% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/novel_alleles.R
\name{findIntercepts}
\alias{findIntercepts}
\title{Find which y-intercepts are above a threshhold}
\usage{
findIntercepts(mut_fracs, y_intercept = 1/8, alpha = 0.05)
}
\arguments{
\item{mut_fracs}{a matrix as returned by \code{trimMutMatrix}, where
rows are named with nucleotide position and columns
are named with sequence-wide mutation count}

\item{y_intercept}{the y-intercept above which positions should be
returned}

\item{alpha}{the alpha cutoff that should be used in calculating
the confidence interval for the y-intercept}
}
\value{
A matrix of mutation frequencies at given positions (rows) as a
          function of sequence-wide mutation count (columns) for the desired
          ranges of each. If there is a problem with the number of sequences,
          etc., \code{NULL} will be returned.
}
\description{
\code{findIntercepts} takes a matrix as returned by \code{trimMutMatrix},
where mutation frequencies at given positions (rows) are calculated as a
function of sequence-wide mutation count (columns), and determines which
y-intercepts (positionalal mutation frequency when sequence-wide mutation
counts equals zero) are predicted to be above a certain threshhold.
}
\details{
The y-intercept is tested by using a t-test to determine the
         range of values likely to contain the intercept. If the lower-bound
         of this confidence interval is greater than the y-intercept cutoff,
         the position will be returned. This is the key step in
         \code{\link{detectNovelV}}.
}
\examples{
# Invent some mutation matrix
mut_fracs = matrix(c(sapply(1:10, function(x) max(rnorm(1, x),0)/20),
                     sapply(1:10, function(x) max(rnorm(1, x),0)/20),
                     sapply(1:10, function(x) max(rnorm(1, x),0)/20),
                     sapply(rep(5,10), function(x) max(rnorm(1, x),0)/10)),
                   nrow=4, byrow=T)
colnames(mut_fracs) = 1:10; rownames(mut_fracs) = 1:4
# Test to see if any have a y-intercept above 1/8 (position 4 should)
findIntercepts(mut_fracs)
}
\seealso{
\code{\link{trimMutMatrix}}, \code{\link{detectNovelV}}
}

