% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/novel_alleles.R
\name{findNucletoideUsage}
\alias{findNucletoideUsage}
\title{Determine nucleotide usage at a given position}
\usage{
findNucletoideUsage(position, samples, germline, mut_counts, mut_min = 1,
  mut_max = 10)
}
\arguments{
\item{position}{an integer representing the IMGT-numbered position of
interest}

\item{samples}{a vector of sample nucleotide sequences}

\item{germline}{a string with the germline nucleotide sequence}

\item{mut_counts}{a vector containing the mutation count of each sample}

\item{mut_min}{the minimum number of sequence-wide mutations for
sequences that will be included in the returned matrix}

\item{mut_max}{the maximum number of sequence-wide mutations for
sequences that will be included in the returned matrix}
}
\value{
A table of nucleotide usage at a given position as a function of
          sequence-wide mutation counts, with the germline base on top and
          the most frequent mutated-to base on the bottom
}
\description{
\code{findNucletoideUsage} determines the nucleotide distribution at a given
IMGT-numbered position as a function of sequence-wide mutation counts.
}
\examples{
# Load example data and germlines
data(sample_db)
data(germline_ighv)

# Single out calls utilizing a particular germline sequence
germ = germline_ighv[1]
matches = grep(names(germ), sample_db$V_CALL, fixed=TRUE)
samples = sample_db$SEQUENCE_IMGT[matches]

# Find mutation counts in those sequences
mut_counts = getMutCount(samples, rep(names(germ), length(samples)), germ)

# Find nucleotide usage at position 2 as a function of mutation count
findNucletoideUsage(2, samples, germ, mut_counts)
}

