% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/genotype.R
\name{findUnmutatedCalls}
\alias{findUnmutatedCalls}
\title{Determine which calls represent an unmutated allele}
\usage{
findUnmutatedCalls(allele_calls, mut_counts, only_unmutated = TRUE)
}
\arguments{
\item{allele_calls}{a vector of strings respresenting Ig allele calls,
where multiple calls are separated by a comma}

\item{mut_counts}{a list containing distance to each germline allele
call within \code{allele_calls}, as returned by
\code{\link{getMutCount}}}

\item{only_unmutated}{if \code{TRUE}, calls where no allele that would
                         represent an unmutated sequence will be omitted from
                         the output}
}
\value{
A vector of strings containing the members of \code{allele_calls}
          that represent unmutated sequences
}
\description{
\code{findUnmutatedCalls} determines which allele calls would represent a
perfect match with the germline sequence, given a vector of allele calls and
mutation counts. In the case of multiple alleles being assigned to a
sequence, only the subset that would represent a perfect match is returned.
}
\examples{
# Load germline database
data(germline_ighv)

# Use createGermlines to insert a mutation into a germline sequence
sample_seqs = c(germline_ighv[2],
                createGermlines(germline_ighv[1], 103, "G"),
                germline_ighv[1],
                germline_ighv[2])

# Pretend that one sample sequence has received an ambiguous allele call
sample_alleles = c(paste(names(germline_ighv[1:2]), collapse=","),
                  names(germline_ighv[2]),
                  names(germline_ighv[1]),
                  names(germline_ighv[2]))

# Compare the sequence to a subset of the germlines
mut_counts = getMutCount(sample_seqs, sample_alleles, germline_ighv)

# Find which of the sample alleles are unmutated
findUnmutatedCalls(sample_alleles, mut_counts)
}

