% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/genotype.R
\name{inferGenotype}
\alias{inferGenotype}
\title{Infer a subject-specific genotype}
\usage{
inferGenotype(allele_calls, fraction_to_explain = 7/8, gene_cutoff = 0.001)
}
\arguments{
\item{allele_calls}{a vector of strings respresenting Ig allele
calls of unmutated sequences from a single
subject}

\item{fraction_to_explain}{the portion of each gene that must be
explained by the alleles that will be included
in the genotype}

\item{gene_cutoff}{either a number of sequences or a fraction of
                               the length of \code{allele_calls} denoting the
                               minimum number of times a gene must be
                               observed in \code{allele_calls} to be included
                               in the genotype}
}
\value{
A table of alleles denoting the genotype of the subject
}
\description{
\code{inferGenotype} infers an subject's genotype by finding the minimum
number set of alleles that can explain the majority of each gene's calls. The
most common allele of each gene is included in the genotype first, and the
next most common allele is added until the desired fraction of alleles can be
explained. In this way, mistaken allele calls (resulting from sequences which
by chance have been mutated to look like another allele) can be removed.
}
\details{
Allele calls representing cases where multiple alleles have been
          assigned to a single sample sequence are rare among unmutated
          sequences but may result if nucleotides for certain positions are
          not available. Calls containing multiple alleles are treated as
          belonging to all groups until one of those groups is included in
          the genotype.
}
\note{
This method works best with data derived from blood, where a large
          portion of sequences are expected to be unmutated. Ideally, there
          should be hundreds of allele calls per gene in the input.
}
\examples{
# Load example data; we'll pretend allele calls are unmutated
data(sample_db)

# Infer the V genotype
inferGenotype(sample_db[,"V_CALL"])

# Inger the J genotype
inferGenotype(sample_db[,"J_CALL"])
}

