% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/tigger_wrapper.R
\name{modifyChangeoDb}
\alias{modifyChangeoDb}
\title{Standardize Sample Db data}
\usage{
modifyChangeoDb(sample_db, seq_imgt_col = "SEQUENCE_IMGT",
  v_call_col = "V_CALL", j_call_col = "J_CALL",
  junc_len_col = "JUNCTION_LENGTH", func_col = "FUNCTIONAL",
  cols_to_add = c("V_GENE", "J_GENE", "V_SEQUENCE_IMGT"),
  distinct_seq_only = TRUE, nonempty_seq_only = TRUE,
  functional_seq_only = FALSE, standardize_calls = TRUE,
  factor2char = TRUE)
}
\arguments{
\item{sample_db}{A Change-O db data frame.}

\item{seq_imgt_col}{The name of the column in \code{sample_db}
containing the IMGT-gapped nucleotide sequence.}

\item{v_call_col}{The name of the column in \code{sample_db}
containingthe IMGT-assigned V allele call.}

\item{j_call_col}{The name of the column in \code{sample_db}
containing the IMGT-assigned J allele call.}

\item{junc_len_col}{The name of the column in \code{sample_db}
containing the junction length.}

\item{func_col}{The name of the column in \code{sample_db}
indicating if the sequence is functional.}

\item{cols_to_add}{One or more of \code{"V_GENE"}, \code{"J_GENE"}, or
\code{"V_SEQUENCE_IMGT"}, indicating which columns
should be added. See details for more information.}

\item{distinct_seq_only}{Logical indicating if duplicate IMGT-gapped
sequences should be removed.}

\item{nonempty_seq_only}{Logical indicating if empty sequences should be
removed.}

\item{functional_seq_only}{Logical indicating if nonfunctional sequences
should be removed.}

\item{standardize_calls}{Logical indicating if IMGT-assigned allele calls
should be standardized.}

\item{factor2char}{Logical indicating if columns of type
\code{factor} should be converted to type
\code{character}.}
}
\value{
A corrected Change-O Db data frame
}
\description{
\code{modifyChangeoDb} takes a Change-O Sample Db and modifies it for use
with TIgGER.
}
\details{
The supplied column names will be renamed to the current preferred
names (and utilized for the creation of new columns, if requested). Columns
\code{"V_GENE"}, \code{"J_GENE"}, and \code{"V_SEQUENCE_IMGT"}, if added,
will respectively contain the IMGT-assigned V gene call, the IMGT-assigned J
gene call, and the first 312 nucleotides (FWR1, CDR1, FWR2, CDR2, and FRW3)
of the IMGT-gapped nucleotide sequence.
}
\examples{
data(sample_db)
corrected_sample_db = modifySampleDb(sample_db, cols_to_add = c("V_GENE"))
}

