% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/tigger_wrapper.R
\name{plotJunctionBars}
\alias{plotJunctionBars}
\title{Visualization of J gene usage and junction length}
\usage{
plotJunctionBars(novel)
}
\arguments{
\item{novel}{a list of the type returned by \code{\link{detectNovelV}}}
}
\value{
plot(s) of the frequency of each combination of J gene and
junction length among sequences using potential novel alleles
}
\description{
\code{plotJunctionBars} shows the frequency of each combination of J gene
junction length found among sequences representing unmutated versions of
potential novel alleles.
}
\examples{
\dontrun{
## Load example data and run all aspects of TIgGER (takes a few minutes)
data(sample_db)
data(germline_ighv)
results = runTigger(sample_db, germline_ighv)

## Summarize the detected novel alleles, add them to vector of all alleles
novel_sequences = novelSummary(results, seqs_to_return = "in genotype")
germline_ighv = c(germline_ighv, novel_sequences)
## Plot positional mutation frequency versus sequence-wide mutation count
plotNovelLines(results$novel)
## Plot nucleotide usage at polymorphic positions
plotNovelBars(results$novel)
## Plot J and junction usage for sequences perfectly matching novel alleles
plotJunctionBars(results$novel)

## View the inferred genotype
print(results$genotype)
## Get the nucleotide sequences of all genotype alleles
genotype_sequences = genotypeFasta(results$genotype, germline_ighv)

## Extract the corrected V allele calls and appened them to the data frame
V_CALL_GENOTYPED = results$new_calls
sample_db = cbind(sample_db, V_CALL_GENOTYPED)
}
}
\seealso{
\code{\link{detectNovelV}}, \code{\link{runTigger}}
}

