% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/call_correction.R
\name{reassignAlleles}
\alias{reassignAlleles}
\title{Correct allele calls based on a personalized genotype}
\usage{
reassignAlleles(v_calls, v_sequences, genotype_db)
}
\arguments{
\item{v_calls}{a vector of strings respresenting Ig allele calls for
the sequences in \code{v_sequences}, where multiple
calls are separated by a comma}

\item{v_sequences}{a vector of IMGT-gapped sample V sequences from a
single subject}

\item{genotype_db}{a vector of named nucleotide germline sequences
                        matching the calls detailed in \code{allele_calls}
                        and personalized to the subject}
}
\value{
a list equal in length to \code{v_calls}, best allele call from
          among the sequences listed in \code{genotype_db}
}
\description{
\code{reassignAlleles} uses a subject-specific genotype to correct
correct preliminary allele assignments of a set of sequences derived
from a single subject.
}
\examples{
\dontrun{
## Load example data and run all aspects of TIgGER (takes a few minutes)
data(sample_db)
data(germline_ighv)
results = runTigger(sample_db, germline_ighv)

## Derive the subject-specific Ig sequences
novel_sequences = novelSummary(results, seqs_to_return = "in genotype")
germline_ighv = c(germline_ighv, novel_sequences)
genotype_db = genotypeFasta(sample_output$genotype, germline_ighv)

## Extract the appropriate portions of example data
v_seqs = sapply(sample_db$SEQUENCE_IMGT, substr, 1, 312)

## Derive the vector of corrected calls
corrected_calls = reassignAlleles(sample_db$V_CALL, v_seqs, genotype_db)
}
}

