% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/novel_alleles.R
\name{trimMutMatrix}
\alias{trimMutMatrix}
\title{Trim a mutation summary}
\usage{
trimMutMatrix(mut_summary, mut_min = 1, mut_max = 10, nt_min = 1,
  nt_max = 312, min_seqs = 50, min_frac = 0.75, verbose = F)
}
\arguments{
\item{mut_summary}{a pair of lists as returned by
\code{summarizeMutations}}

\item{mut_min}{the minimum number of sequence-wide mutations for
sequences that will be included in the returned
matrix}

\item{mut_max}{the maximum number of sequence-wide mutations for
sequences that will be included in the returned
matrix}

\item{nt_min}{the first nucleotide position to be included in the
returned matrix}

\item{nt_max}{the last nucleotide position to be included in the
returned matrix}

\item{min_seqs}{the minimum number of total sequences (within the
desired mutational range and nucleotide range)
required for the function to return a value}

\item{min_frac}{the minimum fraction of sequences that must have
usable nucleotides in a given position for that
position to not be made \code{NA}}

\item{verbose}{if \code{TRUE}, a message will be printed when the
input causes a value of \code{NULL} to be returned}
}
\value{
A matrix of mutation frequencies at given positions (rows) as a
          function of sequence-wide mutation count (columns) for the desired
          ranges of each. If there is a problem with the number of sequences,
          etc., \code{NULL} will be returned.
}
\description{
\code{trimMutMatrix} takes a pair of lists as returned by
\code{summarizeMutations} and returns a matrix of mutation frequencies at
given positions (rows) as a function of sequence-wide mutation count
(columns) for the desired ranges of each.
}
\examples{
# Create strings to act as a sample sequences and a reference sequence
seqs = c("----GATA","GAGAGAGA","GATAGGGA","TANA")
ref = "GATAGATA"

# Find the differences/similarities between the two
muts = getMutatedPositions(seqs, ref)
matches = getMutatedPositions(seqs, ref, match_instead =TRUE)

# Find positional mutation and nucleotide counts
mut_mat = summarizeMutations(muts, matches)

# Summarize the frequency for counts above one
trimMutMatrix(mut_mat, mut_max=2, nt_max=8, min_seqs=0, min_frac=0)
}
\seealso{
\code{\link{summarizeMutations}}
}

